# Geofig

[![PyPI][badge-pypi]][project-pypi]
[![Python][badge-pyversion]][project-pyversion]
[![Codeberg][badge-codeberg]][project-codeberg]
[![PDM][badge-pdm]][project-pdm]
[![License][badge-license]][project-license]

## Introduction

Geofig is a Python library to procedurally generate geometric figures as SVG images.

## Features

- uses [SymPy][link-sympy] for geometric objects and computation
- symbolic computation of geometric objects and relationships in Cartesian space
- automatic transformation and layout, rendered into an SVG image
- styling of objects through dynamic inclusion of CSS rules

## Examples

[See examples of Geofig output, with links to source code.][project-examples]


[badge-codeberg]: https://img.shields.io/badge/codeberg-main-blue?logo=codeberg&logoColor=white
[badge-license]: https://img.shields.io/badge/license-0BSD-blue?logo=open+source+initiative&logoColor=white
[badge-pdm]: https://img.shields.io/badge/PDM-managed-blue?logo=pdm&logoColor=white
[badge-pypi]: https://img.shields.io/pypi/v/geofig?color=blue&logo=pypi&logoColor=white
[badge-pyversion]: https://img.shields.io/python/required-version-toml?tomlFilePath=https://codeberg.org/reserata/geofig/raw/branch/main/pyproject.toml&color=blue&logo=python&logoColor=white
[link-sympy]: https://sympy.org/
[project-codeberg]: https://codeberg.org/reserata/geofig/
[project-examples]: https://codeberg.org/reserata/geofig/src/branch/main/examples/README.md
[project-license]: https://codeberg.org/reserata/geofig/src/branch/main/LICENSE
[project-pdm]: https://pdm-project.org/
[project-pypi]: https://pypi.org/project/geofig
[project-pyversion]: https://www.python.org/
